#
# spec file for package lazarus
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
Name:           lazarus
Version:        2.0.4
Release:        5.2
# Please note that the LGPL is modified and this is not multi-licensed, but each component has a separate license chosen.
Summary:        FreePascal RAD IDE and Component Library
License:        GPL-2.0-only AND LGPL-2.0-only AND MPL-1.1
Group:          Development/Languages/Other
Url:            http://www.lazarus.freepascal.org/
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM http://mantis.freepascal.org/view.php?id=31364
Source1:        https://raw.githubusercontent.com/hughsie/fedora-appstream/developerapps/appdata-extra/desktop/lazarus.appdata.xml
Source90:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE lazarus-Makefile_patch.diff -- Change installation path from /usr/share/lazarus to /usr/lib(64)/lazarus
Patch0:         %{name}-Makefile_patch.diff
# PATCH-FIX-OPENSUSE lazarus.desktop.patch -- Fix desktop file
Patch1:         lazarus.desktop.patch
%if 0%{?suse_version} > 1210
BuildRequires:  desktop-file-utils
%else
BuildRequires:  update-desktop-files
%endif
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  fpc >= 3.0.0
BuildRequires:  fpc-src >= 3.0.0
%if 0%{?suse_version} >= 1140
BuildRequires:  hicolor-icon-theme
%endif
%if 0%{?sles_version} == 11
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
%else
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
%endif
%if 0%{?sle_version} >= 120200 || 0%{?suse_version} > 1320
BuildRequires:  libqt5-qtbase-common-devel >= 5.6.0
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
%endif
Requires:       fpc
Requires:       fpc-src
Requires:       gdb
%if 0%{?sles_version} == 11
Requires:       glib2-devel
Requires:       gtk2-devel
%else
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk+-2.0)
%endif
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Lazarus is a Rapid Application Development
tool for the FreePascal compiler using the Lazarus component
library - LCL. The LCL is included in this package.

%package     -n libQt5Pas%{sover}
Summary:        Free Pascal interface to Qt5
License:        LGPL-3.0-only
Group:          System/Libraries

%description -n libQt5Pas%{sover}
Library that allows to use Qt5 with Free Pascal

%package     -n libQt5Pas-devel
Summary:        Free Pascal interface to Qt5
License:        LGPL-3.0-only
Group:          Development/Libraries/Other
Requires:       libQt5Pas%{sover} = %{version}

%description -n libQt5Pas-devel
Development files for Free Pascal interface to Qt5.

%prep
%setup -q -n %{name}
%patch0 -p1
%patch1 -p1

# remove unneeded files
rm -rf debian
rm -rf tools/install/cross_unix/debian_crosswin32/
rm -f tools/install/cross_unix/*deb.*
rm -rf tools/install/debian_*
rm -rf tools/install/freebsd_*
rm -rf tools/install/macosx/
rm -rf tools/install/slacktgz/
rm -rf tools/install/win/
rm -f tools/install/*slacktgz.*

# remove scripts vulnerable to symlink-attacks (bug 460642)
rm tools/install/build_fpc_snaphot_rpm.sh
rm tools/install/check_fpc_dependencies.sh
rm tools/install/create_fpc_deb.sh
rm tools/install/create_fpc_export_tgz.sh
rm tools/install/create_fpc_rpm.sh
rm tools/install/create_fpc-src_rpm.sh
rm tools/install/create_fpc_tgz_from_local_dir.sh
rm tools/install/create_lazarus_export_tgz.sh

# fix lineencodings
dos2unix examples/trayicon/frmtest.*
dos2unix examples/trayicon/wndtray.*

# fix rpmlint error "spurious-executable-perm"
chmod 644 docs/booth/ProdProgEntwMitOpenSourceSystems2007.odp
if [ -n "$SOURCE_DATE_EPOCH" ] ; then
  datestr=$(date -u "-d@$SOURCE_DATE_EPOCH" +%Y/%m/%d)
  sed -i -e 's!{\$I %%date%%}!'"'$datestr'"'!' \
    ide/ideinfodlg.pas ide/aboutfrm.pas ide/idefpcinfo.pas
  touch -d@"$SOURCE_DATE_EPOCH" ide/ideinfodlg.pas ide/aboutfrm.pas ide/idefpcinfo.pas # reset source timestamps because they are embedded in compiled files
fi

# fix shebang
find . \( -name "*.sh" -o -name "*.pl" \) -exec sed -i '1s|#!/usr/bin/env|%{_bindir}/|' {} +

%build
# Don't use -gs (use explicitly "stabs" debuginfo) for compiling lhelp but -g (use the default debuginfo type "dwarf") as in the rest of package's Makefiles
# Fixes the "Stabs debuginfo not supported" error when extracting debug info from the package
sed -i "s/\-gs/\-g/" components/chmhelp/lhelp/Makefile

export FPCDIR=%{_datadir}/fpcsrc/
fpcmake -Tall

MAKEOPTS="-gl -Fl/usr/%{_lib}"
make bigide OPT="$MAKEOPTS"

export LCL_PLATFORM=

# build Qt4 interface
make -C lcl/interfaces/qt all LCL_PLATFORM=qt OPT="-dQT_NATIVE_DIALOGS"

%if 0%{?sle_version} >= 120200 || 0%{?suse_version} > 1320
# build Qt5 interface
make -C lcl/interfaces/qt5 all LCL_PLATFORM=qt5 OPT="-dQT_NATIVE_DIALOGS"

# build libQt5Pas
pushd lcl/interfaces/qt5/cbindings
%qmake5
make %{?_smp_mflags}
popd
%endif

%install
make install \
    INSTALL_PREFIX=%{buildroot}%{_prefix} \
    INSTALL_LIBDIR=%{buildroot}%{_libdir} \
    INSTALL_BINDIR=%{buildroot}%{_bindir} \
    LAZARUS_INSTALL_DIR=%{buildroot}%{_libdir}/%{name} \
    _LIB=%{_lib}

%if 0%{?sle_version} >= 120200 || 0%{?suse_version} > 1320
pushd lcl/interfaces/qt5/cbindings
%qmake5_install
install -Dpm 0644 qt5.pas %{buildroot}%{_datadir}/fpcsrc/packages/qt5/qt5.pas
popd
%endif

# convenience links
for f in lazarus lazbuild startlazarus; do
    rm -f %{buildroot}%{_bindir}/$f
    ln -sf ../%{_lib}/%{name}/$f %{buildroot}%{_bindir}/$f
done
rm -f %{buildroot}%{_bindir}/lazarus-ide
ln -sf ../%{_lib}/%{name}/lazarus %{buildroot}%{_bindir}/lazarus-ide
for f in lazres lrstolfm updatepofiles; do
    ln -sf ../%{_lib}/%{name}/tools/$f %{buildroot}%{_bindir}/$f
    cat %{buildroot}%{_libdir}/%{name}/install/man/man1/${f}.1 | gzip >%{buildroot}%{_mandir}/man1/${f}.1.gz
done

# collect docs and samples
install -dm 755 %{buildroot}%{_defaultdocdir}/%{name}
mv %{buildroot}%{_libdir}/%{name}/examples %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_defaultdocdir}/%{name}/examples %{buildroot}%{_libdir}/%{name}/examples
mv %{buildroot}%{_libdir}/%{name}/docs %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_defaultdocdir}/%{name}/docs %{buildroot}%{_libdir}/%{name}/docs
mv %{buildroot}%{_libdir}/%{name}/COPYING* %{buildroot}%{_libdir}/%{name}/README* %{buildroot}%{_defaultdocdir}/%{name}

# icons
for f in 16 32 48 64 128 256; do
    install -Dpm 0644 images/icons/lazarus${f}x${f}.png %{buildroot}%{_datadir}/icons/hicolor/${f}x${f}/apps/%{name}.png
done

# menu-entry
%if 0%{?suse_version} > 1210
desktop-file-install install/lazarus.desktop
%else
install -Dpm 0644 install/lazarus.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file -n %{name} Development IDE
%endif

# mime info
install -Dpm 0644 install/%{name}-mime.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml

# software gallery metadata
install -Dpm 0644 %{S:1} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

# configs
install -dm 0755 %{buildroot}%{_sysconfdir}/%{name}
sed <tools/install/linux/environmentoptions.xml -e "s#__LAZARUSDIR__#%{_libdir}/%{name}/#" -e "s#__FPCSRCDIR__#%{_datadir}/fpcsrc/#" > %{buildroot}%{_sysconfdir}/%{name}/environmentoptions.xml

# cleanup
rm -rf %{buildroot}%{_libdir}/%{name}/install/man
rm -f %{buildroot}%{_libdir}/%{name}/Makefile.fpc.orig
rm -rf %{buildroot}%{_libdir}/%{name}/lcl/interfaces/qt5/cbindings
%fdupes -s %{buildroot}

%if 0%{?suse_version} <= 1320
%post
%if 0%{?suse_version} >= 1140
%mime_database_post
%icon_theme_cache_post
%desktop_database_post
%else
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
%endif

%postun
%if 0%{?suse_version} >= 1140
%mime_database_postun
%icon_theme_cache_postun
%desktop_database_postun
%else
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
%endif
%endif

%if 0%{?sle_version} >= 120200 || 0%{?suse_version} > 1320
%post -n libQt5Pas%{sover} -p /sbin/ldconfig

%postun -n libQt5Pas%{sover} -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root,-)
%doc %{_mandir}/man1/*
%doc %{_defaultdocdir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/environmentoptions.xml
%{_bindir}/%{name}
%{_bindir}/%{name}-ide
%{_bindir}/lazbuild
%{_bindir}/startlazarus
%{_bindir}/lazres
%{_bindir}/lrstolfm
%{_bindir}/updatepofiles
%{_libdir}/%{name}/
# license is problematic
%exclude %{_libdir}/%{name}/components/aggpas/gpc
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/mimetypes/*.png
%{_datadir}/pixmaps/lazarus.png
%{_datadir}/mime/packages/%{name}.xml
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%if 0%{?sle_version} >= 120200 || 0%{?suse_version} > 1320
%files -n libQt5Pas%{sover}
%defattr(-,root,root,-)
%doc lcl/interfaces/qt5/cbindings/COPYING.TXT
%{_libdir}/libQt5Pas.so.%{sover}*

%files -n libQt5Pas-devel
%defattr(-,root,root,-)
%doc lcl/interfaces/qt5/cbindings/COPYING.TXT
%dir %{_datadir}/fpcsrc
%dir %{_datadir}/fpcsrc/packages
%dir %{_datadir}/fpcsrc/packages/qt5
%{_datadir}/fpcsrc/packages/qt5/qt5.pas
%{_libdir}/libQt5Pas.so
%endif

%changelog
* Tue Aug  6 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.4
  This is a bugfix release. For a complete list of changes see:
  https://wiki.freepascal.org/Lazarus_2.0_fixes_branch#Fixes_for_2.0.4_.28merged.29
* Tue Apr 16 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.2
  This is a bugfix release. For a complete list of changes see:
  http://wiki.freepascal.org/Lazarus_2.0_fixes_branch#Fixes_for_2.0.2_.28Merged.29
* Tue Feb  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.0
  * For a complete list of changes, see:
    http://wiki.freepascal.org/Lazarus_2.0.0_release_notes
- Refreshed lazarus.desktop.patch and lazarus-rpmlintrc
* Tue May 22 2018 aloisio@gmx.com
- Update to version 1.8.4
  This is a bugfix release. For a complete list of changes see:
  http://wiki.freepascal.org/Lazarus_1.8_fixes_branch#Fixes_for_1.8.4_.28merged.29
* Wed Feb 28 2018 aloisio@gmx.com
- Update to version 1.8.2
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.8.0_release_notes
* Thu Jan  4 2018 termim@gmail.com
- fix description fo libQt5Pas packages
* Tue Dec 26 2017 jengelh@inai.de
- Remove bashsisms from %%prep. Replace useless use of cat.
  Fix unusual BuildRequires for sles>=11.
  Trim filler wording from description.
* Sun Dec 17 2017 aloisio@gmx.com
-  Actually install the LCL Qt5 interface
* Sun Dec 17 2017 ecsos@opensuse.org
- add/download right/original source
- add missing %%defattr(-,root,root,-) for new libQt5Pas and
  libQt5Pas-devel files section
- rebase lazarus.desktop.patch
* Wed Dec  6 2017 aloisio@gmx.com
- Update to version 1.8.0, for a complete changelog see:
  http://wiki.freepascal.org/Lazarus_1.8.0_release_notes
- Refreshed lazarus.desktop.patch
- Enabled Qt5 and built libQt5Pas for supported targets
* Fri May  5 2017 jengelh@inai.de
- Avoid bashisms in %%prep. Escape call involving "!" with single
  quotes to really be sure that there is no history expansion.
* Tue May  2 2017 bwiedemann@suse.com
- Make build more reproducible
* Tue Feb  7 2017 mailaender@opensuse.org
- Add an appdata.xml file for https://en.opensuse.org/openSUSE:AppStore
- Don't package lazarus/components/aggpas/gpc (problematic license)
* Fri Nov 18 2016 aloisio@gmx.com
- Update to 1.6.2
  This is a bugfix release. For a complete list of changes see:
  http://wiki.lazarus.freepascal.org/Lazarus_1.6_fixes_branch#Fixes_for_1.6.2_.28merged.29
* Mon Jun 27 2016 termim@gmail.com
- Update to 1.6.0
  http://wiki.freepascal.org/Lazarus_1.6.0_release_notes
  http://wiki.lazarus.freepascal.org/User_Changes_3.0.0
* Sun Oct 18 2015 ecsos@opensuse.org
- update to 1.4.4
  This is a bug fix release. For complete list of changes see
  http://wiki.freepascal.org/Lazarus_1.4_fixes_branch#Fixes_for_1.4.4_.28Merged.29
* Thu Jul 23 2015 ecsos@opensuse.org
- update to 1.4.2
  This is a bug fix release. For complete list of changes see
  http://wiki.freepascal.org/Lazarus_1.4_fixes_branch#Fixes_for_1.4.2_.28Merged.29
* Wed Apr 22 2015 ecsos@opensuse.org
- update to 1.4.0
  This is a major release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.4.0_release_notes
* Sat Oct 18 2014 ecsos@opensuse.org
- update to 1.2.6
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.2_fixes_branch#Fixes_for_1.2.6_.28Merged.29
* Wed Jul  9 2014 ecsos@opensuse.org
- update to 1.2.4
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.2_fixes_branch#Fixes_for_1.2.4_.28Merged.29
* Thu Jan  9 2014 ecsos@opensuse.org
- update to 1.0.14
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.14_.28Merged.29
* Wed Oct 16 2013 ecsos@opensuse.org
- Update to 1.0.12
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.12_.28Merged.29
* Wed Aug  7 2013 asterios.dramis@gmail.com
- Update to 1.0.10:
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.10_.28Merged.29
- Use the package's internal desktop file instead of a custom one. Added a
  patch (lazarus.desktop.patch) to fix it.
- Removed ImageMagick build requirement (not needed).
- Use desktop-file-utils instead of update-desktop-files for openSUSE > 12.1.
  Added desktop-file-utils build requirement for this.
- Install icons in the hicolor icon directory. Added
  icon_theme_cache_post/icon_theme_cache_postun entries for openSUSE >= 11.4 to
  update the icon cache. Added hicolor-icon-theme build requirement for this.
- Added desktop_database_post/desktop_database_postun entries for
  openSUSE >= 11.4 since the package defines a MIME handler. Added
  desktop-file-utils post/postun runtime requirement for this.
- Use mime_database_post/mime_database_postun entries for openSUSE >= 11.4
  instead of /usr/bin/update-mime-database.
* Tue Jan  1 2013 mailaender@opensuse.org
- Update to 1.0.4
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.4_.28Merged.29
- formal RPMlint fixes
* Mon Dec 10 2012 Greg.Freemyer@gmail.com
- add Requires fpc-src
  If you try to run lazarus without fpc-src you get an error that certain functionality is lost.
  "The sources of the Free Pascal packages are required for browsing and code completion."
* Mon Oct 29 2012 svalx@svalx.net
- Fix building for SLE_11.
* Tue Oct 16 2012 asterios.dramis@gmail.com
- Update to 1.0.2
  This is a bug fix release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_fixes_branch#Fixes_for_1.0.2_.28Merged.29
- Removed libdb-4_5-devel build requirement (not needed).
- Don't strip binaries (let rpm extract the debug info from the package).
- Don't use -gs (use explicitly "stabs" debuginfo) for compiling lhelp but -g
  (use the default debuginfo type "dwarf") as in the rest of package's
  Makefiles. Fixes the "Stabs debuginfo not supported" error when extracting
  debug info from the package.
* Thu Oct  4 2012 asterios.dramis@gmail.com
- Fix lazarus dir in /etc/lazarus/environmentoptions.xml (use
  /usr/lib64/lazarus for x86_64).
- Removed gtk2 build requirement (not needed).
- Use Requires(post/postun) for shared-mime-info instead of PreReq for the
  post/postun update-mime-database execution.
- Removed Fedora related stuff (incomplete).
- Spec file updates based also on spec-cleaner run.
- Updated lazarus.desktop file to be xdg compatible.
* Sun Sep 23 2012 termim@gmail.com
- Update to 1.0.0
  This is a major release. For complete list of changes see
  http://wiki.lazarus.freepascal.org/Lazarus_1.0_release_notes
* Fri Apr  1 2011 termim@gmail.com
- Update to 0.9.30
* Tue Nov  3 2009 Toni Graffy <toni@links2linux.de> - 0.9.28.2-1.pm.1
- fixed configfile environmentoptions.xml
* Sun Nov  1 2009 Toni Graffy <toni@links2linux.de> - 0.9.28.2-0.pm.1
- update to 0.9.28.2
- This release fixes compiling a test application without saving (missing
  project1.lrs). The Lazarus directory is now set correctly by the deb package.
  Some other small fixes are also included.
* Tue Oct 27 2009 Toni Graffy <toni@links2linux.de> - 0.9.28-0.pm.1
- update to 0.9.28
-  In this major release, the IDE has many source editor improvements like display
  of "double width" fonts (such as Eastern, Japanese, Chinese, and Arabic), better
  code folding, highlighting, syncro editing, and persistent blocks. The debugger
  has assembler windows, easier exception handling, and breakpoint properties. The
  LCL now uses GTK2 as the default widgetset on Linux and BSD and includes the
  TMonitor class for multi-monitor support. Refactoring of LCL reduced the minimum
  size of executables by about 15%%. The support of TFrame support has improved, so
  you can visually nest designers in the IDE.
* Mon May  4 2009 Toni Graffy <toni@links2linux.de> - 0.9.26.2-0.pm.3
- rebuild against fpc-2.2.4
* Mon Mar 23 2009 Toni Graffy <toni@links2linux.de> - 0.9.26.2-0.pm.2
- update to 0.9.26.2 (release-tarball)
* Sat Feb 28 2009 Toni Graffy <toni@links2linux.de> - 0.9.26.2-0.pm.1
- update to 0.9.26.2
  svn co https://lazarus.svn.sourceforge.net/svnroot/lazarus/tags/lazarus_0_9_26_2 lazarus
* Sat Nov  1 2008 Toni Graffy <toni@links2linux.de> - 0.9.26-0.pm.2
- rebuild against fpc-2.2.2-0.pm.2
* Thu Oct 30 2008 Toni Graffy <toni@links2linux.de> - 0.9.26-0.pm.1
- initial build for packman (fpc-2.2.2 is working with this version)
- based on fedora spec-file from Lubomir Rintel <lkundrak@v3.sk>
